-- I recommend matching thread name & folder name!
dynamic_radar = ScriptThread("cge_dynamic_radar")

-- Run
function dynamic_radar:Run()

	-- USER OPTIONS (set to true or false)
	
		local mod_enabled = true			-- Enable/Disable
		local toggle_key = KEY_F8			-- See http://www.wiki.gtalua.com/index.php/KEY_Constants
		local hide_police_blips = true		-- Hides police on radar
		local exterior_radar = true			-- Always show whole map
		local autohide_radar = true			-- Audo-hides the radar
		local autohide_hud = true			-- Auto-hides the HUD
		local autohide_objective = true		-- Auto-hides the current objective
		local d_pad_radar = false			-- D-Pad down will enable radar
		local d_pad_hud = true				-- D-Pad down will enable HUD
		local d_pad_objective = true		-- D-Pad down will enable objective
		local phone_radar = true			-- Phone will enable radar
		local phone_hud = false				-- Phone will enable HUD
		local phone_objective = false		-- Phone will enable objective
		local waypoint_radar = false		-- Waypoints enable radar
		local vehicle_radar = false			-- Vehicles enable radar
		local d_pad_timer = 300				-- D-Pad time length (depends on framerate, try 600 for 60fps)
		local hide_help = false				-- Hides help text with HUD
		local hide_mp_bar = true			-- Hides the multiplayer rank bar
		local hide_reticle = true			-- Hides the crosshairs (press D-Pad Up to unhide)
	
	-------------------------------------------------------------
		
	local new_message = true
	local delay_timer = 0
	local message_timer = 0
	local wait_timer = 0
	local d_pad_pressed = false
	local phone_active = false
	local display_radar = not autohide_radar
	local display_hud = not autohide_hud
	local objective_hidden = autohide_objective
	
	while self:IsRunning() do
		
		-- Enable/Disable Mod
		if IsKeyDown (toggle_key) then
			if mod_enabled then
				mod_enabled = false
			else
				mod_enabled = true
				new_message = true
				delay_timer = 0
				message_timer = 0
				wait_timer = 0
				d_pad_pressed = false
				phone_active = false
				display_radar = not autohide_radar
				display_hud = not autohide_hud
				objective_hidden = autohide_objective
			end
		end
		
		-- Mod Enabled
		if mod_enabled then
				
			-- Player Info
			local player_ped_id = natives.PLAYER.PLAYER_PED_ID()
			
			-- Reticle
			if hide_reticle and not natives.CONTROLS.IS_CONTROL_PRESSED(2, 42) then -- D-Pad Up while aiming (zoom in)
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(14)
			end
			
			-- Police Blips
			if hide_police_blips then
				natives.PLAYER.SET_POLICE_RADAR_BLIPS(false)
			else
				natives.PLAYER.SET_POLICE_RADAR_BLIPS(true)
			end
			
			-- Exterior Radar
			if exterior_radar then
				natives.UI.SET_RADAR_AS_EXTERIOR_THIS_FRAME()
			end
			
			-- MP Rank Bar
			if hide_mp_bar then
				natives.UI.HIDE_SCRIPTED_HUD_COMPONENT_THIS_FRAME(19)
			end
			
			-- D-Pad Down
			if natives.CONTROLS.IS_CONTROL_PRESSED(2, 20)
			and not natives.CONTROLS.IS_CONTROL_PRESSED(2, 25) -- Aim
			and not natives.CONTROLS.IS_CONTROL_PRESSED(2, 37) -- Weapon Select
			then
				d_pad_pressed = true
			end
			
			if d_pad_pressed then
				wait_timer = wait_timer + 1
				
				if wait_timer > d_pad_timer then
					d_pad_pressed = false
					wait_timer = 0
				end
			end
				
			-- Phone Activated
			if not natives.CONTROLS.IS_CONTROL_ENABLED(2, 20) then
				phone_active = true
			else
				phone_active = false
			end
			
			-- Radar
			if not autohide_radar then
				display_radar = true
			else
				if (d_pad_pressed and d_pad_radar)
				or (phone_active and phone_radar)
				or (natives.UI.IS_WAYPOINT_ACTIVE() and waypoint_radar)
				or (natives.PED.IS_PED_IN_ANY_VEHICLE(player_ped_id, false) and vehicle_radar)then
					display_radar = true
				else
					display_radar = false
				end
				
			end
			
			-- HUD
			if not autohide_hud then
				display_hud = true
			else
				if ((d_pad_pressed and d_pad_hud)
				or (phone_active and phone_hud))
				and not natives.CONTROLS.IS_CONTROL_PRESSED(2, 25) -- Aim
				then
					display_hud = true
				else
					display_hud = false
				end
			end
			
			-- Objective
			if not autohide_objective then
				objective_hidden = false
			else
				if (d_pad_pressed and d_pad_objective)
				or (phone_active and phone_objective)
				then
					objective_hidden = false
				else
					objective_hidden = true
				end
			end
			
		-- DISPLAY	
			
			-- Hide Radar
			if display_radar then
				natives.UI.DISPLAY_RADAR(true)
			else
				natives.UI.DISPLAY_RADAR(false)
			end
			
			-- Hide Hud
			if not display_hud then
				
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(0)  -- Hud?
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(1)  -- Stars
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(2)  -- Weapon
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(3)  -- Cash
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(4)  -- MP Cash
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(5)  -- MP Messages
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(6)  -- Vehicle Name
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(7)  -- Area Name
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(8)  -- Unused?
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(9)  -- Street Name
				natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(13) -- Cash Change
				
				if hide_help then
					natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(10) -- Help Text
					natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(11) -- Floating Help 1
					natives.UI.HIDE_HUD_COMPONENT_THIS_FRAME(12) -- Floating Help 2
					natives.UI.HIDE_HELP_TEXT_THIS_FRAME() -- ?
				end
				
			end
			
			-- Hide Objective Message
			if objective_hidden then
				if natives.UI.IS_MESSAGE_BEING_DISPLAYED() then
					if new_message then
						delay_timer = delay_timer + 1
						if delay_timer > 200 then
							new_message = false
						end
					else
						natives.UI.CLEAR_PRINTS()
						message_timer = 0
					end
				else
					if not new_message then	
						message_timer = message_timer + 1
						if message_timer > 300 then
							new_message = true
							delay_timer = 0
						end
					end	
				end
			end
		
		-- Mod disabled
		else
			-- The radar is the only element that doesn't reset itself
			natives.UI.DISPLAY_RADAR(true)
		end
		
		-- Wait
		self:Wait(1)
		
	end
end

-- OnError
function dynamic_radar:OnError()
	print("dynamic_radar Thread caused an error!")
	self:Reset()
end

-- Register
dynamic_radar:Register()